## Build/install process use Python distutils. ##

Tests use "nose" framework: http://somethingaboutorange.com/mrl/projects/nose/1.0.0/

## Running tests ##

To run tests,

* unit tests

`nosetests -c nose_unit.cfg`
